Ragrank API documentation
==========================
Ragrank is a user-friendly Python library created to make evaluating Retrieval Augmented Generation (RAG) models easier.

.. autofunction:: ragrank.evaluate
    
.. toctree::
   :caption: Table of Contents
   :maxdepth: 1

   bridge/index
   dataset/index
   evaluation/index
   integrations/index
   llm/index
   metric/index
   prompt/index
   utils/index

